@@ -1,6 +1,6 @@
 package MARC::Moose::Field;
 {
-  $MARC::Moose::Field::VERSION = '0.019';
+  $MARC::Moose::Field::VERSION = '0.020';
 }
 # ABSTRACT: Marc field base object
 
@@ -8,7 +8,6 @@ use namespace::autoclean;
 use Moose;
 use Moose::Util::TypeConstraints;
 
-
 subtype 'Tag'
     => as 'Str'
     => where { $_ =~ /^\d{3}$/ }
@@ -17,6 +16,15 @@ subtype 'Tag'
 has tag => ( is => 'rw', isa => 'Tag', required => 1, );
 
 
+sub clone {
+    my ($self, $tag) = @_;
+
+    my $field = MARC::Moose::Field->new( tag => $self->tag );
+    $field->tag($tag) if $tag;
+    return $field;
+}
+
+
 sub as_formatted {
     my $self = shift;
     return $self->tag;
@@ -38,7 +46,20 @@ MARC::Moose::Field - Marc field base object
 
 =head1 VERSION
 
-version 0.019
+version 0.020
+
+=head1 ATTRIBUTES
+
+=head2 tag
+
+3-digits identifing a field. Required.
+
+=head1 METHODS
+
+=head2 clone([$tag])
+
+Return a new field cloning the field. If tag is provided, the cloned field tag
+is changed.
 
 =head1 SEE ALSO
 
