@@ -1,6 +1,6 @@
 package MARC::Moose::Record;
 {
-  $MARC::Moose::Record::VERSION = '0.019';
+  $MARC::Moose::Record::VERSION = '0.020';
 }
 # ABSTRACT: MARC::Moose bibliographic record
 
@@ -14,6 +14,7 @@ use MARC::Moose::Formater::Legacy;
 use MARC::Moose::Formater::Marcxml;
 use MARC::Moose::Formater::Text;
 use MARC::Moose::Formater::Yaml;
+use MARC::Moose::Formater::UnimarcToMarc21;
 use MARC::Moose::Parser::Iso2709;
 use MARC::Moose::Parser::MarcxmlSax;
 use MARC::Moose::Parser::Legacy;
@@ -38,20 +39,21 @@ has fields => (
 
 # Les formater standards
 my $formater = {
-    iso2709 => MARC::Moose::Formater::Iso2709->new(),
-    json    => MARC::Moose::Formater::Json->new(),
-    legacy  => MARC::Moose::Formater::Legacy->new(),
-    marcxml => MARC::Moose::Formater::Marcxml->new(),
-    text    => MARC::Moose::Formater::Text->new(),
-    yaml    => MARC::Moose::Formater::Yaml->new(),
+    iso2709         => MARC::Moose::Formater::Iso2709->new(),
+    json            => MARC::Moose::Formater::Json->new(),
+    legacy          => MARC::Moose::Formater::Legacy->new(),
+    marcxml         => MARC::Moose::Formater::Marcxml->new(),
+    text            => MARC::Moose::Formater::Text->new(),
+    yaml            => MARC::Moose::Formater::Yaml->new(),
+    unimarctomarc21 => MARC::Moose::Formater::UnimarcToMarc21->new(),
 };
 
 # Les parser standards
 my $parser = {
-    iso2709 => MARC::Moose::Parser::Iso2709->new(),
-    marcxml => MARC::Moose::Parser::MarcxmlSax->new(),
-    legacy  => MARC::Moose::Parser::Legacy->new(),
-    yaml    => MARC::Moose::Parser::Yaml->new(),
+    iso2709         => MARC::Moose::Parser::Iso2709->new(),
+    marcxml         => MARC::Moose::Parser::MarcxmlSax->new(),
+    legacy          => MARC::Moose::Parser::Legacy->new(),
+    yaml            => MARC::Moose::Parser::Yaml->new(),
 };
 
 
@@ -175,7 +177,7 @@ MARC::Moose::Record - MARC::Moose bibliographic record
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 DESCRIPTION
 
